"""Mineral, gas, supply, and army values for units.

"""
from typing import Dict, TypedDict

from sc2.ids.unit_typeid import UnitTypeId as UnitID


class UnitData(TypedDict):
    minerals: int
    gas: int
    supply: int
    army_value: float
    radius: float
    flying: bool

# Zerg building data includes Drone cost
UNIT_DATA: Dict[UnitID, Dict] = {
    UnitID.SCV: {
        "minerals": 50,
        "gas": 0,
        "supply": 1,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.MULE: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.MARINE: {
        "minerals": 50,
        "gas": 0,
        "supply": 1,
        "army_value": 1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.MARAUDER: {
        "minerals": 100,
        "gas": 25,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5625,
        "flying": False,
    },
    UnitID.REAPER: {
        "minerals": 50,
        "gas": 50,
        "supply": 1,
        "army_value": 1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.GHOST: {
        "minerals": 150,
        "gas": 125,
        "supply": 2,
        "army_value": 2,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.HELLION: {
        "minerals": 100,
        "gas": 0,
        "supply": 2,
        "army_value": 2,
        "radius": 0.625,
        "flying": False,
    },
    UnitID.HELLIONTANK: {
        "minerals": 100,
        "gas": 0,
        "supply": 2,
        "army_value": 2,
        "radius": 0.625,
        "flying": False,
    },
    UnitID.WIDOWMINE: {
        "minerals": 75,
        "gas": 25,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.WIDOWMINEBURROWED: {
        "minerals": 75,
        "gas": 25,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.SIEGETANK: {
        "minerals": 150,
        "gas": 125,
        "supply": 3,
        "army_value": 3,
        "radius": 0.875,
        "flying": False,
    },
    UnitID.SIEGETANKSIEGED: {
        "minerals": 150,
        "gas": 125,
        "supply": 3,
        "army_value": 3,
        "radius": 0.875,
        "flying": False,
    },
    UnitID.CYCLONE: {
        "minerals": 150,
        "gas": 100,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.THOR: {
        "minerals": 300,
        "gas": 200,
        "supply": 6,
        "army_value": 6,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.THORAP: {
        "minerals": 300,
        "gas": 200,
        "supply": 6,
        "army_value": 6,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.VIKINGASSAULT: {
        "minerals": 150,
        "gas": 75,
        "supply": 2,
        "army_value": 2,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.VIKINGFIGHTER: {
        "minerals": 150,
        "gas": 75,
        "supply": 2,
        "army_value": 2,
        "radius": 0.75,
        "flying": True,
    },
    UnitID.MEDIVAC: {
        "minerals": 100,
        "gas": 100,
        "supply": 2,
        "army_value": 2,
        "radius": 0.75,
        "flying": True,
    },
    UnitID.LIBERATOR: {
        "minerals": 150,
        "gas": 150,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": True,
    },
    UnitID.LIBERATORAG: {
        "minerals": 150,
        "gas": 150,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": True,
    },
    UnitID.BANSHEE: {
        "minerals": 150,
        "gas": 100,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": True,
    },
    UnitID.RAVEN: {
        "minerals": 100,
        "gas": 200,
        "supply": 2,
        "army_value": 2,
        "radius": 0.625,
        "flying": True,
    },
    UnitID.BATTLECRUISER: {
        "minerals": 400,
        "gas": 300,
        "supply": 6,
        "army_value": 7,
        "radius": 1.25,
        "flying": True,
    },
    UnitID.POINTDEFENSEDRONE: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 1,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.PROBE: {
        "minerals": 50,
        "gas": 0,
        "supply": 1,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.ZEALOT: {
        "minerals": 100,
        "gas": 0,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.SENTRY: {
        "minerals": 50,
        "gas": 100,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.STALKER: {
        "minerals": 125,
        "gas": 50,
        "supply": 2,
        "army_value": 2,
        "radius": 0.625,
        "flying": False,
    },
    UnitID.ADEPT: {
        "minerals": 100,
        "gas": 25,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.ADEPTPHASESHIFT: {
        "minerals": 100,
        "gas": 25,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.HIGHTEMPLAR: {
        "minerals": 50,
        "gas": 150,
        "supply": 2,
        "army_value": 2,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.DARKTEMPLAR: {
        "minerals": 125,
        "gas": 125,
        "supply": 2,
        "army_value": 2,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.ARCHON: {
        "minerals": 175,
        "gas": 275,
        "supply": 4,
        "army_value": 5,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.OBSERVER: {
        "minerals": 25,
        "gas": 75,
        "supply": 1,
        "army_value": 0.25,
        "radius": 0.5,
        "flying": True,
    },
    UnitID.OBSERVERSIEGEMODE: {
        "minerals": 25,
        "gas": 75,
        "supply": 1,
        "army_value": 0.25,
        "radius": 0.5,
        "flying": True,
    },
    UnitID.WARPPRISM: {
        "minerals": 200,
        "gas": 0,
        "supply": 2,
        "army_value": 2,
        "radius": 0.875,
        "flying": True,
    },
    UnitID.WARPPRISMPHASING: {
        "minerals": 200,
        "gas": 0,
        "supply": 2,
        "army_value": 2,
        "radius": 0.875,
        "flying": True,
    },
    UnitID.IMMORTAL: {
        "minerals": 275,
        "gas": 100,
        "supply": 4,
        "army_value": 4,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.COLOSSUS: {
        "minerals": 300,
        "gas": 200,
        "supply": 6,
        "army_value": 6,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.DISRUPTOR: {
        "minerals": 150,
        "gas": 150,
        "supply": 3,
        "army_value": 3,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.DISRUPTORPHASED: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 3,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.PHOENIX: {
        "minerals": 150,
        "gas": 100,
        "supply": 2,
        "army_value": 2,
        "radius": 0.75,
        "flying": True,
    },
    UnitID.VOIDRAY: {
        "minerals": 250,
        "gas": 150,
        "supply": 4,
        "army_value": 4,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.ORACLE: {
        "minerals": 150,
        "gas": 150,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": True,
    },
    UnitID.TEMPEST: {
        "minerals": 250,
        "gas": 175,
        "supply": 5,
        "army_value": 5,
        "radius": 1.25,
        "flying": True,
    },
    UnitID.CARRIER: {
        "minerals": 350,
        "gas": 250,
        "supply": 6,
        "army_value": 8,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.INTERCEPTOR: {
        "minerals": 15,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 1.25,
        "flying": True,
    },
    UnitID.MOTHERSHIP: {
        "minerals": 300,
        "gas": 300,
        "supply": 8,
        "army_value": 8,
        "radius": 2.75,
        "flying": True,
    },
    UnitID.LARVA: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 0.125,
        "flying": False,
    },
    UnitID.EGG: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 0.125,
        "flying": False,
    },
    UnitID.DRONE: {
        "minerals": 50,
        "gas": 0,
        "supply": 1,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.DRONEBURROWED: {
        "minerals": 50,
        "gas": 0,
        "supply": 1,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.QUEEN: {
        "minerals": 150,
        "gas": 0,
        "supply": 2,
        "army_value": 2,
        "radius": 0.875,
        "flying": False,
    },
    UnitID.QUEENBURROWED: {
        "minerals": 150,
        "gas": 0,
        "supply": 2,
        "army_value": 2,
        "radius": 0.875,
        "flying": False,
    },
    UnitID.ZERGLING: {
        "minerals": 25,
        "gas": 0,
        "supply": 0.5,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.ZERGLINGBURROWED: {
        "minerals": 25,
        "gas": 0,
        "supply": 0.5,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.BANELINGCOCOON: {
        "minerals": 25,
        "gas": 25,
        "supply": 0.5,
        "army_value": 1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.BANELING: {
        "minerals": 25,
        "gas": 25,
        "supply": 0.5,
        "army_value": 1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.BANELINGBURROWED: {
        "minerals": 25,
        "gas": 25,
        "supply": 0.5,
        "army_value": 1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.ROACH: {
        "minerals": 75,
        "gas": 25,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.ROACHBURROWED: {
        "minerals": 75,
        "gas": 25,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": False,
    },
    UnitID.RAVAGER: {
        "minerals": 75 + 25,
        "gas": 75 + 25,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.RAVAGERBURROWED: {
        "minerals": 75 + 25,
        "gas": 75 + 25,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.RAVAGERCOCOON: {
        "minerals": 75 + 25,
        "gas": 75 + 25,
        "supply": 3,
        "army_value": 3,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.HYDRALISK: {
        "minerals": 100,
        "gas": 50,
        "supply": 2,
        "army_value": 2,
        "radius": 0.625,
        "flying": False,
    },
    UnitID.HYDRALISKBURROWED: {
        "minerals": 100,
        "gas": 50,
        "supply": 2,
        "army_value": 2,
        "radius": 0.625,
        "flying": False,
    },
    UnitID.LURKERMP: {
        "minerals": 50 + 100,
        "gas": 100 + 50,
        "supply": 3,
        "army_value": 3,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.LURKERMPBURROWED: {
        "minerals": 50 + 100,
        "gas": 100 + 50,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.LURKERMPEGG: {
        "minerals": 50 + 100,
        "gas": 100 + 50,
        "supply": 3,
        "army_value": 3,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.INFESTOR: {
        "minerals": 100,
        "gas": 150,
        "supply": 2,
        "army_value": 2,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.INFESTEDTERRANSEGG: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.INFESTEDTERRAN: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.INFESTORTERRAN: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.INFESTORBURROWED: {
        "minerals": 100,
        "gas": 150,
        "supply": 2,
        "army_value": 2,
        "radius": 0.75,
        "flying": False,
    },
    UnitID.SWARMHOSTMP: {
        "minerals": 100,
        "gas": 75,
        "supply": 3,
        "army_value": 3,
        "radius": 0.8125,
        "flying": False,
    },
    UnitID.SWARMHOSTBURROWEDMP: {
        "minerals": 100,
        "gas": 75,
        "supply": 3,
        "army_value": 3,
        "radius": 0.8125,
        "flying": False,
    },
    UnitID.LOCUSTMP: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.LOCUSTMPFLYING: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.5,
        "radius": 0.375,
        "flying": True,
    },
    UnitID.ULTRALISK: {
        "minerals": 300,
        "gas": 200,
        "supply": 6,
        "army_value": 6,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.ULTRALISKBURROWED: {
        "minerals": 300,
        "gas": 200,
        "supply": 6,
        "army_value": 6,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.OVERLORD: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 0.1,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.OVERLORDCOCOON: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 0.1,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.OVERLORDTRANSPORT: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 0.5,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.TRANSPORTOVERLORDCOCOON: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 0.1,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.OVERSEER: {
        "minerals": 150,
        "gas": 50,
        "supply": 0,
        "army_value": 0.5,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.OVERSEERSIEGEMODE: {
        "minerals": 150,
        "gas": 50,
        "supply": 0,
        "army_value": 0.5,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.CHANGELING: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.CHANGELINGMARINE: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.CHANGELINGMARINESHIELD: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.CHANGELINGZEALOT: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "flying": False
    },
    UnitID.CHANGELINGZERGLING: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.CHANGELINGZERGLINGWINGS: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.MUTALISK: {
        "minerals": 100,
        "gas": 100,
        "supply": 2,
        "army_value": 2,
        "radius": 0.5,
        "flying": True,
    },
    UnitID.CORRUPTOR: {
        "minerals": 150,
        "gas": 100,
        "supply": 2,
        "army_value": 2,
        "radius": 0.625,
        "flying": True,
    },
    UnitID.VIPER: {
        "minerals": 100,
        "gas": 200,
        "supply": 3,
        "army_value": 3,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.BROODLORD: {
        "minerals": 150 + 150,
        "gas": 150 + 100,
        "supply": 4,
        "army_value": 6,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.BROODLORDCOCOON: {
        "minerals": 150 + 150,
        "gas": 150 + 100,
        "supply": 4,
        "army_value": 6,
        "radius": 1.0,
        "flying": True,
    },
    UnitID.BROODLING: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.01,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.COMMANDCENTER: {
        "minerals": 400,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": False,
    },
    UnitID.COMMANDCENTERFLYING: {
        "minerals": 400,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": True,
    },
    UnitID.ORBITALCOMMAND: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": True,
    },
    UnitID.ORBITALCOMMANDFLYING: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": True,
    },
    UnitID.PLANETARYFORTRESS: {
        "minerals": 150,
        "gas": 150,
        "supply": 0,
        "army_value": 5,
        "radius": 2.5,
        "flying": False,
    },
    UnitID.SUPPLYDEPOT: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.SUPPLYDEPOTLOWERED: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.REFINERY: {
        "minerals": 75,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.BARRACKS: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.BARRACKSFLYING: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": True,
    },
    UnitID.ENGINEERINGBAY: {
        "minerals": 125,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.BUNKER: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 5,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.MISSILETURRET: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 1,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.AUTOTURRET: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 1,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.SENSORTOWER: {
        "minerals": 125,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.FACTORY: {
        "minerals": 150,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.FACTORYFLYING: {
        "minerals": 150,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": True,
    },
    UnitID.GHOSTACADEMY: {
        "minerals": 150,
        "gas": 50,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.ARMORY: {
        "minerals": 150,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.STARPORT: {
        "minerals": 150,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.STARPORTFLYING: {
        "minerals": 150,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": True,
    },
    UnitID.FUSIONCORE: {
        "minerals": 150,
        "gas": 150,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.TECHLAB: {
        "minerals": 125,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.BARRACKSTECHLAB: {
        "minerals": 125,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.FACTORYTECHLAB: {
        "minerals": 125,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.STARPORTTECHLAB: {
        "minerals": 125,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.REACTOR: {
        "minerals": 50,
        "gas": 50,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.BARRACKSREACTOR: {
        "minerals": 50,
        "gas": 50,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.FACTORYREACTOR: {
        "minerals": 50,
        "gas": 50,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.STARPORTREACTOR: {
        "minerals": 50,
        "gas": 50,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.NEXUS: {
        "minerals": 400,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": False,
    },
    UnitID.PYLON: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.ASSIMILATOR: {
        "minerals": 75,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.GATEWAY: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.FORGE: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.PHOTONCANNON: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 3,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.SHIELDBATTERY: {
        "minerals": 100,
        "gas": 0,
        "supply": 0,
        "army_value": 2,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.WARPGATE: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.CYBERNETICSCORE: {
        "minerals": 150,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.TWILIGHTCOUNCIL: {
        "minerals": 150,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.ROBOTICSFACILITY: {
        "minerals": 200,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.STARGATE: {
        "minerals": 150,
        "gas": 150,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.TEMPLARARCHIVE: {
        "minerals": 150,
        "gas": 200,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.DARKSHRINE: {
        "minerals": 150,
        "gas": 150,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.ROBOTICSBAY: {
        "minerals": 150,
        "gas": 150,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.FLEETBEACON: {
        "minerals": 300,
        "gas": 200,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.ORACLESTASISTRAP: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.HATCHERY: {
        "minerals": 300 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": False,
    },
    UnitID.EXTRACTOR: {
        "minerals": 25 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.SPAWNINGPOOL: {
        "minerals": 200 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.EVOLUTIONCHAMBER: {
        "minerals": 75 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.SPINECRAWLER: {
        "minerals": 100 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 3,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.SPINECRAWLERUPROOTED: {
        "minerals": 100 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 3,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.SPORECRAWLER: {
        "minerals": 75 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 3,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.SPORECRAWLERUPROOTED: {
        "minerals": 75 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 3,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.ROACHWARREN: {
        "minerals": 150 + 50,
        "gas": 0,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.BANELINGNEST: {
        "minerals": 100 + 50,
        "gas": 50,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.INFESTATIONPIT: {
        "minerals": 150 + 50,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.LAIR: {
        "minerals": 450 + 50,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": False,
    },
    UnitID.HIVE: {
        "minerals": 650 + 50,
        "gas": 250,
        "supply": 0,
        "army_value": 0,
        "radius": 2.5,
        "flying": False,
    },
    UnitID.HYDRALISKDEN: {
        "minerals": 100 + 50,
        "gas": 100,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.LURKERDENMP: {
        "minerals": 150 + 50,
        "gas": 150,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.SPIRE: {
        "minerals": 200 + 50,
        "gas": 200,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.NYDUSNETWORK: {
        "minerals": 150 + 50,
        "gas": 200,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.NYDUSCANAL: {
        "minerals": 50,
        "gas": 50,
        "supply": 0,
        "army_value": 7,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.ULTRALISKCAVERN: {
        "minerals": 150 + 50,
        "gas": 200,
        "supply": 0,
        "army_value": 0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.GREATERSPIRE: {
        "minerals": 300 + 50,
        "gas": 350,
        "supply": 0,
        "army_value": 0,
        "radius": 1.0,
        "flying": False,
    },
    UnitID.CREEPTUMOR: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.CREEPTUMORBURROWED: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.CREEPTUMORQUEEN: {
        "minerals": 0,
        "gas": 0,
        "supply": 0,
        "army_value": 0.1,
        "radius": 0.375,
        "flying": False,
    },
    UnitID.REFINERYRICH: {
        "minerals": 75,
        "gas": 0,
        "supply": 0,
        "army_value": 0.0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.ASSIMILATORRICH: {
        "minerals": 75,
        "gas": 0,
        "supply": 0,
        "army_value": 0.0,
        "radius": 1.5,
        "flying": False,
    },
    UnitID.EXTRACTORRICH: {
        "minerals": 75,
        "gas": 0,
        "supply": 0,
        "army_value": 0.0,
        "radius": 1.5,
        "flying": False,
    },
}
